==> api-0.7.1-sources.jar: eu/fispace/api/DomainRetail.java <==
/**
 * Copyright (C) 2008-2013 LimeTri. All rights reserved.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */

package eu.fispace.api;

import eu.agrosense.api.platform.PostCapability;
import eu.fispace.api.pi.PushShipmentMessage;
import javax.ws.rs.core.Response;

/**
 *
 * @author Timon Veenstra <timon@agrosense.eu>
 */
public class DomainRetail {
    public static final String DOMAIN = "domain/pi";
    //PushShipmentMessage
    public static final PostCapability<PushShipmentMessage, Response> RECEIVE_SHIPMENT_MESSAGE = (PostCapability<PushShipmentMessage, Response>)new PostCapability<PushShipmentMessage, Response>()
            .withDomain(DOMAIN)
            .withName("push shipment message")
            .withResource("PushShipmentMessage")
            .withRequestMessageClass(PushShipmentMessage.class);          
}

==> api-0.7.2-sources.jar: eu/fispace/api/DomainRetail.java <==
/**
 * Copyright (C) 2008-2013 LimeTri. All rights reserved.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */

package eu.fispace.api;

import eu.agrosense.api.platform.PostCapability;
import eu.fispace.api.pi.ShipmentMessage;
import javax.ws.rs.core.Response;

/**
 *
 * @author Timon Veenstra <timon@agrosense.eu>
 */
public class DomainRetail {
    public static final String DOMAIN = "retail";
    //PushShipmentMessage
    public static final PostCapability<ShipmentMessage, Response> RECEIVE_SHIPMENT_MESSAGE = (PostCapability<ShipmentMessage, Response>)new PostCapability<ShipmentMessage, Response>()
            .withDomain(DOMAIN)
            .withName("push shipment message")
            .withResource("PushShipmentMessage")
            .withRequestMessageClass(ShipmentMessage.class);          
}
